All of lore.kernel.org
 help / color / mirror / Atom feed
* + listh-add-list_singleton-fix.patch added to -mm tree
@ 2008-03-18  5:13 akpm
  0 siblings, 0 replies; only message in thread
From: akpm @ 2008-03-18  5:13 UTC (permalink / raw)
  To: mm-commits; +Cc: mhiramat, a.p.zijlstra


The patch titled
     list.h: rename list_singleton to list_is_singular
has been added to the -mm tree.  Its filename is
     listh-add-list_singleton-fix.patch

Before you just go and hit "reply", please:
   a) Consider who else should be cc'ed
   b) Prefer to cc a suitable mailing list as well
   c) Ideally: find the original patch on the mailing list and do a
      reply-to-all to that, adding suitable additional cc's

*** Remember to use Documentation/SubmitChecklist when testing your code ***

See http://www.zip.com.au/~akpm/linux/patches/stuff/added-to-mm.txt to find
out what to do about this

The current -mm tree may be found at http://userweb.kernel.org/~akpm/mmotm/

------------------------------------------------------
Subject: list.h: rename list_singleton to list_is_singular
From: Masami Hiramatsu <mhiramat@redhat.com>

Rename list_singleton to list_is_singular.

Signed-off-by: Masami Hiramatsu <mhiramat@redhat.com>
Cc: Peter Zijlstra <a.p.zijlstra@chello.nl>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---

 include/linux/list.h |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff -puN include/linux/list.h~listh-add-list_singleton-fix include/linux/list.h
--- a/include/linux/list.h~listh-add-list_singleton-fix
+++ a/include/linux/list.h
@@ -212,10 +212,10 @@ static inline int list_empty_careful(con
 }
 
 /**
  * list_singleton - tests whether a list has just one entry.
  * @head: the list to test.
  */
-static inline int list_singleton(const struct list_head *head)
+static inline int list_is_singular(const struct list_head *head)
 {
 	return !list_empty(head) && (head->next == head->prev);
 }
_

Patches currently in -mm which might be from mhiramat@redhat.com are

kprobes-kprobe-booster-for-ia64.patch
kprobes-kprobe-booster-for-ia64-fix.patch
listh-add-list_singleton.patch
listh-add-list_singleton-fix.patch
kprobes-add-unregister_kprobes-for-batch-registration.patch
kprobes-add-unregister_kprobes-for-batch-registration-fix.patch
kprobes-add-unregister_kretprobes-for-batch-registration.patch
kprobes-add-unregister_jprobes-for-batch-registration.patch
kprobes-update-document-about-batch-registration.patch


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2008-03-18  5:14 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -212,10 +212,10 @@ static inline int list_empty_careful(con
 
 /**
- * list_singleton - tests whether a list has just one entry.
+ * list_is_singular - tests whether a list has just one entry.
  * @head: the list to test.
  */
2008-03-18  5:13 + listh-add-list_singleton-fix.patch added to -mm tree akpm

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.